Usage
=====

.. _installation:

Installation
------------

To use image_utils, first install it using pip:

.. code-block:: console

   (.venv) $ pip install image_utils


To get started:

>>> from image_utils import Im
>>> Im(image).get_torch
# (h w c), np.uint8, [0, 255]
